/*-*- coding: utf-8 -*-                                                      */
/*copyright 2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.          */
/*contact http://www.logilab.fr -- mailto:contact@logilab.fr                 */
/*                                                                           */
/*This program is free software: you can redistribute it and/or modify it    */
/* under the terms of the GNU Lesser General Public License as published     */
/*by the Free Software Foundation, either version 2.1 of the License, or     */
/* (at your option)any later version.                                        */
/*                                                                           */
/*This program is distributed in the hope that it will be useful, but        */
/*WITHOUT ANY WARRANTY; without even the implied warranty of                 */
/*MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser    */
/* General Public License for more details.                                  */
/*                                                                           */
/*You should have received a copy of the GNU Lesser General Public License   */
/* along with this program. If not, see <http://www.gnu.org/licenses/>.      */

[id^="slickgrid-coverage-"] {
    background: #eeeeee;
    border: 1px dotted #aaaaaa !important;
}

[class^="slickgrid_"], [class^="slickgrid_"] div{
    -webkit-box-sizing: content-box !important;
    -moz-box-sizing: content-box !important;
    box-sizing: content-box !important;
}

.slick-cell a{
    color: #428bca;
}

.slick-columnpicker input{
    height: 15px;
    font-size: 10px;
}

.slick-columnpicker label{
    font-weight: unset;
}